/*
 * Copyright 2008 Google Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.gwtorbit.client.widgets;

import com.google.gwt.user.client.ui.VerticalPanel;
import com.gwtorbit.client.model.UiData;
import com.gwtorbit.client.model.UiDataDisplay;
import com.gwtorbit.client.model.UiErrors;

public class UiRichTextAreaAndToolbar extends VerticalPanel implements UiDataDisplay {

	private UiRichTextArea richTextArea;
	
	private UiRichTextAreaToolbar toolbar;
	
	public UiRichTextAreaAndToolbar() {
		richTextArea = new UiRichTextArea();
		toolbar = new UiRichTextAreaToolbar();
		
		toolbar.setUiRichTextArea(richTextArea);
		
		add(toolbar);
		add(richTextArea);
	}
	
	public void setInputWidth(String width) {
		richTextArea.setWidth(width);
	}
	
	public void setInputHeight(String height) {
		richTextArea.setHeight(height);
	}
	
	public void setWysiwygDisplayed(boolean wysiwygDisplayed) {
		richTextArea.setWysiwygDisplayed(wysiwygDisplayed);
	}
	
	public void setHTML(String html) {
		richTextArea.setHTML(html);
	}
	
	public String getHTML() {
		return richTextArea.getHTML();
	}
	
	private boolean enabled = true;
	
	public void setEnabled(boolean enabled) {
		this.enabled = enabled;
		
		richTextArea.setEnabled(enabled);
		//toolbar.setEnabled(enabled);
	}

	public boolean isEnabled() {
		return enabled;
	}

	public void displayData(UiData uiData) {
		richTextArea.displayData(uiData);
	}

	public void getData(UiData uiData, UiErrors errors, String errorPrefix) {
		richTextArea.getData(uiData, errors, errorPrefix);
	}

	public void clearData() {
		richTextArea.clearData();
	}

	public String getDataName() {
		return richTextArea.getDataName();
	}

	public void setDataName(String dataName) {
		richTextArea.setDataName(dataName);
	}

	public void setMandatory(boolean mandatory) {
		richTextArea.setMandatory(mandatory);
	}

	public boolean isMandatory() {
		return richTextArea.isMandatory();
	}

	public boolean getIgnore() {
		return richTextArea.getIgnore();
	}

	public void setIgnore(boolean ignore) {
		richTextArea.setIgnore(ignore);
	}

}
